% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Cape.R
\name{Cape-class}
\alias{Cape-class}
\alias{Cape}
\title{The CAPE data object}
\description{
The CAPE data object

The CAPE data object
}
\details{
Class \code{Cape} defines a CAPE analysis object.
}
\section{Slots}{

\describe{
\item{\code{parameter_file}}{string, full path to YAML file with initialization
parameters}

\item{\code{yaml_parameters}}{string representing YAML CAPE parameters. See the
vignette for more descriptions of individual parameter settings.}

\item{\code{results_path}}{string, full path to directory for storing results
(optional, a directory will be created if one is not specified)}

\item{\code{save_results}}{Whether to save cape results. Defaults to FALSE.}

\item{\code{use_saved_results}}{Whether to use existing results from a 
previous run. This can save time if re-running an analysis, but
can lead to problems if the old run and new run have competing settings.
If errors arise, and use_saved_results is set to TRUE, try setting it 
to FALSE, or deleting previous results.}

\item{\code{pheno}}{A matrix containing the traits to be analyzed. Traits are in
columns and individuals are in rows.}

\item{\code{chromosome}}{A vector the same length as the number of markers indicating
which chromosome each marker lives on.}

\item{\code{marker_num}}{A vector the same length as the number of markers indicating
the index of each marker}

\item{\code{marker_location}}{A vector the same length as the number of markers indicating
the genomic position of each marker. The positions are primarily used for plotting
and can be in base pairs, centiMorgans, or dummy variables.}

\item{\code{marker_selection_method}}{A string indicating how markers should be 
selected for the pairscan. Options are "top_effects" or "from_list."
If "top_effects," markers are selected using main effect sizes. 
If "from_list" markers are specified using a vector of marker names. 
See \code{\link{select_markers_for_pairscan}}.}

\item{\code{geno_names}}{The dimnames of the genotype array. The genotype array is a three-dimensional
array in which rows are individuals, columns are alleles, and the third dimension houses
the markers. Genotypes are pulled for analysis using \code{\link{get_geno}} based on
geno_names. Only the individuals, alleles, and markers listed in geno_names are
taken from the genotype matrix. Functions that remove markers and individuals from
analysis always operate on geno_names in addition to other relevant slots.
The names of geno_names must be "mouse", "allele", "locus."}

\item{\code{geno}}{A three dimensional array holding genotypes for each animal for each allele
at each marker. The genotypes are continuously valued probabilities ranging from 0 to 1. 
The dimnames of geno must be "mouse", "allele", and "locus," even if the individuals are
not mice.}

\item{\code{geno_for_pairscan}}{A two-dimensional matrix holding the genotypes that will be analyzed
in the pairscan. Alleles are in columns and individuals are in rows. As in the geno array, 
values are continuous probabilities ranging from 0 to 1.}

\item{\code{peak_density}}{The density parameter for \code{\link{select_markers_for_pairscan}}.
Determines how densely markers under an individual effect size peak are selected 
for the pairscan if marker_selection_method is TRUE. Defaults to 0.5.}

\item{\code{window_size}}{The window size used by \code{\link{select_markers_for_pairscan}}.
It specifies how many markers are used to smooth effect size curves for automatic peak
identification. If set to NULL, window_size is determined automatically. Used when 
marker_selection_method is TRUE.}

\item{\code{tolerance}}{The wiggle room afforded to \code{\link{select_markers_for_pairscan}} in 
finding a target number of markers. If num_alleles_in_pairscan is 100 and the tolerance 
is 5, the algorithm will stop when it identifies anywhere between 95 and 105 markers 
for the pairscan.}

\item{\code{ref_allele}}{A string of length 1 indicating which allele to use as the reference allele.
In two-parent crosses, this is usually allele A. In DO/CC populations, we recommend using
B as the reference allele. B is the allele from the C57Bl6/J mouse, which is often used as
a reference strain.}

\item{\code{alpha}}{The significance level for calculating effect size thresholds in the 
\code{\link{singlescan}}. If singlescan_perm is 0, this parameter is ignored.}

\item{\code{covar_table}}{A matrix of covariates with covariates in columns and individuals
in rows. Must be numeric.}

\item{\code{num_alleles_in_pairscan}}{The number of alleles to test in the pairwise scan. 
Because Cape is computationally intensive, we usually need to test only a subset
of available markers in the pairscan, particularly if the kinship correction is
being used.}

\item{\code{max_pair_cor}}{the maximum Pearson correlation between two markers. If their
correlation exceeds this value, they will not be tested against each other in the
pairscan. This threshold is set to prevent false positive arising from testing
highly correlated markers. If this value is set to NULL, min_per_genotype must
be specified.}

\item{\code{min_per_genotype}}{minimum The minimum number of individuals allowable per
genotype combination in the pair scan. If for a given marker pair, one of the 
genotype combinations is underrepresented, the marker pair is not tested. If 
this value is NULL, max_pair_cor must be specified.}

\item{\code{pairscan_null_size}}{The total size of the null distribution.
This is DIFFERENT than the number of permutations to run. Each permutation
generates n choose 2 elements for the pairscan. So for example, a permutation
that tests 100 pairs of markers will generate a null distribution of size 4950.
This process is repeated until the total null size is reached. If the null size
is set to 5000, two permutations of 100 markers would be done to get to a null
distribution size of 5000.}

\item{\code{p_covar}}{A vector of strings specifying the names of covariates derived
from traits. See \code{\link{pheno2covar}}.}

\item{\code{g_covar}}{A vector of strings specifying the names of covariates derived 
from genetic markers. See \code{\link{marker2covar}}.}

\item{\code{p_covar_table}}{A matrix holding the individual values for each
trait-derived covariate. 
See \code{\link{pheno2covar}}.}

\item{\code{g_covar_table}}{A matrix holding the individual values for each 
marker-derived covariate. See \code{\link{marker2covar}}.}

\item{\code{model_family}}{Indicates the model family of the phenotypes
This can be either "gaussian" or "binomial". If this argument
is length 1, all phenotypes will be assigned to the same
family. Phenotypes can be assigned different model families by
providing a vector of the same length as the number of phenotypes,
indicating how each phenotype should be modeled. See \code{\link{singlescan}}.}

\item{\code{scan_what}}{A string indicating whether "eigentraits", "normalized_traits", or 
"raw_traits" should be analyzed. See \code{\link{get_pheno}}.}

\item{\code{ET}}{A matrix holding the eigentraits to be analyzed.}

\item{\code{singular_values}}{Added by \code{\link{get_eigentraits}}. A vector holding 
the singular values from the singular
value decomposition of the trait matrix. They are used in rotating the 
final direct influences back to trait space from eigentrait space. See
\code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{right_singular_vectors}}{Added by \code{\link{get_eigentraits}}. A matrix 
containing the right singular vectors from the singular
value decomposition of the trait matrix. They are used in rotating the 
final direct influences back to trait space from eigentrait space. See
\code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{traits_scaled}}{Whether the traits should be mean-centered and standardized
before analyzing.}

\item{\code{traits_normalized}}{Whether the traits should be rank Z normalized before
analyzing.}

\item{\code{var_to_var_influences_perm}}{added in \code{\link{error_prop}} 
The list of results from the error propagation of permuted coefficients.}

\item{\code{var_to_var_influences}}{added in \code{\link{error_prop}} 
The list of results from the error propagation of coefficients.}

\item{\code{pval_correction}}{Options are "holm", "hochberg", "hommel", "bonferroni", "BH", "BY","fdr", "none"}

\item{\code{linkage_blocks_collapsed}}{A list containing assignments of markers to linkage blocks 
calculated by \code{\link{linkage_blocks_network}} and \code{\link{plot_network}}.
In this list there can be multiple markers assigned to a single linkage block.}

\item{\code{linkage_blocks_full}}{A list containing assignments of markers to linkage blocks 
when no linkage blocks are calculated. In this list there can only be one marker
per "linkage block". See \code{\link{linkage_blocks_network}} and \code{\link{plot_network}}.}

\item{\code{var_to_var_p_val}}{The final table of cape interaction results calculated by \code{\link{error_prop}}.}

\item{\code{max_var_to_pheno_influence}}{The final table of cape direct influences of markers to traits
calculated by \code{\link{direct_influence}}.}

\item{\code{collapsed_net}}{An adjacency matrix holding significant cape interactions between
linkage blocks. See \code{\link{plot_network}} and \code{\link{get_network}}.}

\item{\code{full_net}}{An adjacency matrix holding significant cape interactions between
individual markers. See \code{\link{plot_network}} and \code{\link{get_network}}.}

\item{\code{use_kinship}}{Whether to use a kinship correction in the analysis.}

\item{\code{kinship_type}}{Which type of kinship matrix to use. Either "overall" 
for the overall kinship matrix or "ltco" for leave-two-chromosomes-out.}

\item{\code{transform_to_phenospace}}{whether to transform to phenospace or not.}
}}

\examples{
\dontrun{
param_file <- "cape_parameters.yml"
results_path = "."
cape_obj <- read_population("cross.csv")
combined_obj <- cape2mpp(cape_obj)
pheno_obj <- combined_obj$data_obj
geno_obj <- combined_obj$geno_obj

data_obj <- Cape$new(parameter_file = param_file,
results_path = results_path, pheno = pheno_obj$pheno, chromosome = pheno_obj$chromosome, 
marker_num = pheno_obj$marker_num, marker_location = pheno_obj$marker_location, 
geno_names = pheno_obj$geno_names, geno = geno_obj)
}

}
\section{Public fields}{
\if{html}{\out{<div class="r6-fields">}}
\describe{
\item{\code{parameter_file}}{full path to YAML file with initialization parameters.}

\item{\code{yaml_parameters}}{string representing YAML CAPE parameters. See the vignette for more descriptions 
of individual parameter settings.}

\item{\code{results_path}}{string, full path to directory for storing results (optional, a directory will be 
created if one is not specified).}

\item{\code{save_results}}{Whether to save cape results. Defaults to FALSE.}

\item{\code{use_saved_results}}{Whether to use existing results from a previous run. This can save time if 
re-running an analysis, but can lead to problems if the old run and new run have competing settings.
If errors arise, and use_saved_results is set to TRUE, try setting it to FALSE, or deleting previous results.}

\item{\code{pheno}}{A matrix containing the traits to be analyzed. Traits are in columns and individuals are in rows.}

\item{\code{chromosome}}{A vector the same length as the number of markers indicating which chromosome each marker lives on.}

\item{\code{marker_num}}{A vector the same length as the number of markers indicating the index of each marker.}

\item{\code{marker_location}}{A vector the same length as the number of markers indicating the genomic position of each marker.
The positions are primarily used for plotting and can be in base pairs, centiMorgans, or dummy variables.}

\item{\code{geno_names}}{The dimnames of the genotype array. The genotype array is a three-dimensional array in which rows 
are individuals, columns are alleles, and the third dimension houses the markers. Genotypes are pulled for analysis 
using \code{\link{get_geno}} based on geno_names. Only the individuals, alleles, and markers listed in geno_names are
taken from the genotype matrix. Functions that remove markers and individuals from analysis always operate on geno_names 
in addition to other relevant slots. The names of geno_names must be "mouse", "allele", "locus."}

\item{\code{geno}}{A three dimensional array holding genotypes for each animal for each allele at each marker. The genotypes
are continuously valued probabilities ranging from 0 to 1. The dimnames of geno must be "mouse", "allele", and "locus,"
even if the individuals are not mice.}

\item{\code{peak_density}}{The density parameter for 
\code{\link{select_markers_for_pairscan}}.  Determines how densely
markers under an individual effect size peak are selected for the 
pairscan if marker_selection_method is TRUE.
Defaults to 0.5.}

\item{\code{window_size}}{The window size used by 
\code{\link{select_markers_for_pairscan}}. It specifies how many markers
are used to smooth effect size curves for automatic peak identification. If set to NULL, window_size is determined
automatically. Used when marker_selection_method is TRUE.}

\item{\code{tolerance}}{The wiggle room afforded to \code{\link{select_markers_for_pairscan}} in finding a target number
of markers. If num_alleles_in_pairscan is 100 and the tolerance is 5, the algorithm will stop when it identifies
anywhere between 95 and 105 markers for the pairscan.}

\item{\code{ref_allele}}{A string of length 1 indicating which allele to use as the reference allele. In two-parent crosses,
this is usually allele A. In DO/CC populations, we recommend using B as the reference allele. B is the allele from
the C57Bl6/J mouse, which is often used as a reference strain.}

\item{\code{alpha}}{The significance level for calculating effect size thresholds in the \code{\link{singlescan}}.
If singlescan_perm is 0, this parameter is ignored.}

\item{\code{covar_table}}{A matrix of covariates with covariates in columns and individuals in rows. Must be numeric.}

\item{\code{num_alleles_in_pairscan}}{The number of alleles to test in the pairwise scan. Because Cape is computationally
intensive, we usually need to test only a subset of available markers in the pairscan, particularly if the kinship
correction is being used.}

\item{\code{max_pair_cor}}{The maximum Pearson correlation between two markers. If their correlation exceeds this value,
they will not be tested against each other in the pairscan. This threshold is set to prevent false positive arising
from testing highly correlated markers. If this value is set to NULL, min_per_genotype must be specified.}

\item{\code{min_per_genotype}}{minimum The minimum number of individuals allowable per genotype combination in the pair scan.
If for a given marker pair, one of the genotype combinations is underrepresented, the marker pair is not tested.
If this value is NULL, max_pair_cor must be specified.}

\item{\code{pairscan_null_size}}{The total size of the null distribution. This is DIFFERENT than the number of permutations
to run. Each permutation generates n choose 2 elements for the pairscan. So for example, a permutation that tests 100
pairs of markers will generate a null distribution of size 4950. This process is repeated until the total null size
is reached. If the null size is set to 5000, two permutations of 100 markers would be done to get to a null
distribution size of 5000.}

\item{\code{p_covar}}{A vector of strings specifying the names of covariates derived from traits. See \code{\link{pheno2covar}}.}

\item{\code{g_covar}}{A vector of strings specifying the names of covariates derived from genetic markers.
See \code{\link{marker2covar}}.}

\item{\code{p_covar_table}}{A matrix holding the individual values for each trait-derived covariate. See \code{\link{pheno2covar}}.}

\item{\code{g_covar_table}}{A matrix holding the individual values for each marker-derived covariate. See \code{\link{marker2covar}}.}

\item{\code{model_family}}{Indicates the model family of the phenotypes. This can be either "gaussian" or "binomial".
If this argument is length 1, all phenotypes will be assigned to the same family. Phenotypes can be assigned
different model families by providing a vector of the same length as the number of phenotypes, indicating how
each phenotype should be modeled. See \code{\link{singlescan}}.}

\item{\code{scan_what}}{A string indicating whether "eigentraits", "normalized_traits", or "raw_traits" should be analyzed.
See \code{\link{get_pheno}}.}

\item{\code{ET}}{A matrix holding the eigentraits to be analyzed.}

\item{\code{singular_values}}{Added by \code{\link{get_eigentraits}}. A vector holding the singular values from the singular
value decomposition of the trait matrix. They are used in rotating the final direct influences back to trait space
from eigentrait space. See \code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{right_singular_vectors}}{Added by \code{\link{get_eigentraits}}. A matrix containing the right singular vectors
from the singular value decomposition of the trait matrix. They are used in rotating the final direct influences
back to trait space from eigentrait space. See \code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{traits_scaled}}{Whether the traits should be mean-centered and standardized before analyzing.}

\item{\code{traits_normalized}}{Whether the traits should be rank Z normalized before analyzing.}

\item{\code{var_to_var_influences_perm}}{added in \code{\link{error_prop}}. The list of results from the error propagation
of permuted coefficients.}

\item{\code{var_to_var_influences}}{added in \code{\link{error_prop}}. The list of results from the error propagation of coefficients.}

\item{\code{pval_correction}}{Options are "holm", "hochberg", "hommel", "bonferroni", "BH", "BY","fdr", "none".}

\item{\code{var_to_var_p_val}}{The final table of cape interaction results calculated by \code{\link{error_prop}}.}

\item{\code{max_var_to_pheno_influence}}{The final table of cape direct influences of markers to traits calculated
by \code{\link{direct_influence}}.}

\item{\code{full_net}}{An adjacency matrix holding significant cape interactions between individual markers. See
\code{\link{plot_network}} and \code{\link{get_network}}.}

\item{\code{use_kinship}}{Whether to use a kinship correction in the analysis.}

\item{\code{kinship_type}}{which type of kinship matrix to use}

\item{\code{transform_to_phenospace}}{whether to transform to phenospace or not.}
}
\if{html}{\out{</div>}}
}
\section{Active bindings}{
\if{html}{\out{<div class="r6-active-bindings">}}
\describe{
\item{\code{geno_for_pairscan}}{geno for pairscan}

\item{\code{marker_selection_method}}{marker selection method}

\item{\code{linkage_blocks_collapsed}}{linkage blocks collapsed}

\item{\code{linkage_blocks_full}}{linkage blocks full}

\item{\code{collapsed_net}}{collapsed net}
}
\if{html}{\out{</div>}}
}
\section{Methods}{
\subsection{Public methods}{
\itemize{
\item \href{#method-assign_parameters}{\code{Cape$assign_parameters()}}
\item \href{#method-check_inputs}{\code{Cape$check_inputs()}}
\item \href{#method-check_geno_names}{\code{Cape$check_geno_names()}}
\item \href{#method-new}{\code{Cape$new()}}
\item \href{#method-plotSVD}{\code{Cape$plotSVD()}}
\item \href{#method-plotSinglescan}{\code{Cape$plotSinglescan()}}
\item \href{#method-plotPairscan}{\code{Cape$plotPairscan()}}
\item \href{#method-plotVariantInfluences}{\code{Cape$plotVariantInfluences()}}
\item \href{#method-plotNetwork}{\code{Cape$plotNetwork()}}
\item \href{#method-plotFullNetwork}{\code{Cape$plotFullNetwork()}}
\item \href{#method-writeVariantInfluences}{\code{Cape$writeVariantInfluences()}}
\item \href{#method-set_pheno}{\code{Cape$set_pheno()}}
\item \href{#method-set_geno}{\code{Cape$set_geno()}}
\item \href{#method-create_covar_table}{\code{Cape$create_covar_table()}}
\item \href{#method-save_rds}{\code{Cape$save_rds()}}
\item \href{#method-read_rds}{\code{Cape$read_rds()}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-assign_parameters"></a>}}
\if{latex}{\out{\hypertarget{method-assign_parameters}{}}}
\subsection{Method \code{assign_parameters()}}{
Assigns variables from the parameter file to attributes in the Cape object.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$assign_parameters()}\if{html}{\out{</div>}}
}

}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-check_inputs"></a>}}
\if{latex}{\out{\hypertarget{method-check_inputs}{}}}
\subsection{Method \code{check_inputs()}}{
Checks the dimensionality of inputs and its consistency.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$check_inputs()}\if{html}{\out{</div>}}
}

}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-check_geno_names"></a>}}
\if{latex}{\out{\hypertarget{method-check_geno_names}{}}}
\subsection{Method \code{check_geno_names()}}{
Checks genotype names.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$check_geno_names()}\if{html}{\out{</div>}}
}

}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-new"></a>}}
\if{latex}{\out{\hypertarget{method-new}{}}}
\subsection{Method \code{new()}}{
Initialization method.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$new(
  parameter_file = NULL,
  yaml_parameters = NULL,
  results_path = NULL,
  save_results = FALSE,
  use_saved_results = TRUE,
  pheno = NULL,
  chromosome = NULL,
  marker_num = NULL,
  marker_location = NULL,
  geno_names = NULL,
  geno = NULL,
  .geno_for_pairscan = NULL,
  peak_density = NULL,
  window_size = NULL,
  tolerance = NULL,
  ref_allele = NULL,
  alpha = NULL,
  covar_table = NULL,
  num_alleles_in_pairscan = NULL,
  max_pair_cor = NULL,
  min_per_genotype = NULL,
  pairscan_null_size = NULL,
  p_covar = NULL,
  g_covar = NULL,
  p_covar_table = NULL,
  g_covar_table = NULL,
  model_family = NULL,
  scan_what = NULL,
  ET = NULL,
  singular_values = NULL,
  right_singular_vectors = NULL,
  traits_scaled = NULL,
  traits_normalized = NULL,
  var_to_var_influences_perm = NULL,
  var_to_var_influences = NULL,
  pval_correction = NULL,
  var_to_var_p_val = NULL,
  max_var_to_pheno_influence = NULL,
  full_net = NULL,
  use_kinship = NULL,
  kinship_type = NULL,
  transform_to_phenospace = NULL
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{parameter_file}}{string, full path to YAML file with initialization
parameters}

\item{\code{yaml_parameters}}{string representing YAML CAPE parameters. See the
vignette for more descriptions of individual parameter settings.}

\item{\code{results_path}}{string, full path to directory for storing results
(optional, a directory will be created if one is not specified)}

\item{\code{save_results}}{Whether to save cape results. Defaults to TRUE.}

\item{\code{use_saved_results}}{Whether to use existing results from a 
previous run. This can save time if re-running an analysis, but
can lead to problems if the old run and new run have competing settings.
If errors arise, and use_saved_results is set to TRUE, try setting it 
to FALSE, or deleting previous results.}

\item{\code{pheno}}{A matrix containing the traits to be analyzed. Traits are in
columns and individuals are in rows.}

\item{\code{chromosome}}{A vector the same length as the number of markers indicating
which chromosome each marker lives on.}

\item{\code{marker_num}}{A vector the same length as the number of markers indicating
the index of each marker}

\item{\code{marker_location}}{A vector the same length as the number of markers indicating
the genomic position of each marker. The positions are primarily used for plotting
and can be in base pairs, centiMorgans, or dummy variables.}

\item{\code{geno_names}}{The dimnames of the genotype array. The genotype array is a three-dimensional
array in which rows are individuals, columns are alleles, and the third dimension houses
the markers. Genotypes are pulled for analysis using \code{\link{get_geno}} based on
geno_names. Only the individuals, alleles, and markers listed in geno_names are
taken from the genotype matrix. Functions that remove markers and individuals from
analysis always operate on geno_names in addition to other relevant slots.
The names of geno_names must be "mouse", "allele", "locus."}

\item{\code{geno}}{A three dimensional array holding genotypes for each animal for each allele
at each marker. The genotypes are continuously valued probabilities ranging from 0 to 1. 
The dimnames of geno must be "mouse", "allele", and "locus," even if the individuals are
not mice.}

\item{\code{.geno_for_pairscan}}{A two-dimensional matrix holding the genotypes that will be analyzed
in the pairscan. Alleles are in columns and individuals are in rows. As in the geno array, 
values are continuous probabilities ranging from 0 to 1.}

\item{\code{peak_density}}{The density parameter for \code{\link{select_markers_for_pairscan}}.
Determines how densely markers under an individual effect size peak are selected 
for the pairscan if marker_selection_method is TRUE. Defaults to 0.5.}

\item{\code{window_size}}{The window size used by \code{\link{select_markers_for_pairscan}}.
It specifies how many markers are used to smooth effect size curves for automatic peak
identification. If set to NULL, window_size is determined automatically. Used when 
marker_selection_method is TRUE.}

\item{\code{tolerance}}{The wiggle room afforded to \code{\link{select_markers_for_pairscan}} in 
finding a target number of markers. If num_alleles_in_pairscan is 100 and the tolerance 
is 5, the algorithm will stop when it identifies anywhere between 95 and 105 markers 
for the pairscan.}

\item{\code{ref_allele}}{A string of length 1 indicating which allele to use as the reference allele.
In two-parent crosses, this is usually allele A. In DO/CC populations, we recommend using
B as the reference allele. B is the allele from the C57Bl6/J mouse, which is often used as
a reference strain.}

\item{\code{alpha}}{The significance level for calculating effect size thresholds in the 
\code{\link{singlescan}}. If singlescan_perm is 0, this parameter is ignored.}

\item{\code{covar_table}}{A matrix of covariates with covariates in columns and individuals
in rows. Must be numeric.}

\item{\code{num_alleles_in_pairscan}}{The number of alleles to test in the pairwise scan. 
Because Cape is computationally intensive, we usually need to test only a subset
of available markers in the pairscan, particularly if the kinship correction is
being used.}

\item{\code{max_pair_cor}}{the maximum Pearson correlation between two markers. If their
correlation exceeds this value, they will not be tested against each other in the
pairscan. This threshold is set to prevent false positive arising from testing
highly correlated markers. If this value is set to NULL, min_per_genotype must
be specified.}

\item{\code{min_per_genotype}}{minimum The minimum number of individuals allowable per
genotype combination in the pair scan. If for a given marker pair, one of the 
genotype combinations is underrepresented, the marker pair is not tested. If 
this value is NULL, max_pair_cor must be specified.}

\item{\code{pairscan_null_size}}{The total size of the null distribution.
This is DIFFERENT than the number of permutations to run. Each permutation
generates n choose 2 elements for the pairscan. So for example, a permutation
that tests 100 pairs of markers will generate a null distribution of size 4950.
This process is repeated until the total null size is reached. If the null size
is set to 5000, two permutations of 100 markers would be done to get to a null
distribution size of 5000.}

\item{\code{p_covar}}{A vector of strings specifying the names of covariates derived
from traits. See \code{\link{pheno2covar}}.}

\item{\code{g_covar}}{A vector of strings specifying the names of covariates derived 
from genetic markers. See \code{\link{marker2covar}}.}

\item{\code{p_covar_table}}{A matrix holding the individual values for each
trait-derived covariate. See \code{\link{pheno2covar}}.}

\item{\code{g_covar_table}}{A matrix holding the individual values for each 
marker-derived covariate. See \code{\link{marker2covar}}.}

\item{\code{model_family}}{Indicates the model family of the phenotypes
This can be either "gaussian" or "binomial". If this argument
is length 1, all phenotypes will be assigned to the same
family. Phenotypes can be assigned different model families by
providing a vector of the same length as the number of phenotypes,
indicating how each phenotype should be modeled. See \code{\link{singlescan}}.}

\item{\code{scan_what}}{A string indicating whether "eigentraits", "normalized_traits", or 
"raw_traits" should be analyzed. See \code{\link{get_pheno}}.}

\item{\code{ET}}{A matrix holding the eigentraits to be analyzed.}

\item{\code{singular_values}}{Added by \code{\link{get_eigentraits}}. A vector holding 
the singular values from the singular
value decomposition of the trait matrix. They are used in rotating the 
final direct influences back to trait space from eigentrait space. See
\code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{right_singular_vectors}}{Added by \code{\link{get_eigentraits}}. A matrix 
containing the right singular vectors from the singular
value decomposition of the trait matrix. They are used in rotating the 
final direct influences back to trait space from eigentrait space. See
\code{\link{get_eigentraits}} and \code{\link{direct_influence}}.}

\item{\code{traits_scaled}}{Whether the traits should be mean-centered and standardized
before analyzing.}

\item{\code{traits_normalized}}{Whether the traits should be rank Z normalized before
analyzing.}

\item{\code{var_to_var_influences_perm}}{added in \code{\link{error_prop}} 
The list of results from the error propagation of permuted coefficients.}

\item{\code{var_to_var_influences}}{added in \code{\link{error_prop}} 
The list of results from the error propagation of coefficients.}

\item{\code{pval_correction}}{Options are "holm", "hochberg", "hommel", "bonferroni", "BH", "BY","fdr", "none"}

\item{\code{var_to_var_p_val}}{The final table of cape interaction results calculated by \code{\link{error_prop}}.}

\item{\code{max_var_to_pheno_influence}}{The final table of cape direct influences of markers to traits
calculated by \code{\link{direct_influence}}.}

\item{\code{full_net}}{An adjacency matrix holding significant cape interactions between
individual markers. See \code{\link{plot_network}} and \code{\link{get_network}}.}

\item{\code{use_kinship}}{Whether to use a kinship correction in the analysis.}

\item{\code{kinship_type}}{Which type of kinship matrix to use. Either "overall" or "ltco."}

\item{\code{transform_to_phenospace}}{whether to transform to phenospace or not.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotSVD"></a>}}
\if{latex}{\out{\hypertarget{method-plotSVD}{}}}
\subsection{Method \code{plotSVD()}}{
Plot Eigentraits
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotSVD(filename)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotSinglescan"></a>}}
\if{latex}{\out{\hypertarget{method-plotSinglescan}{}}}
\subsection{Method \code{plotSinglescan()}}{
Plot results of single-locus scans
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotSinglescan(
  filename,
  singlescan_obj,
  width = 20,
  height = 6,
  units = "in",
  res = 300,
  standardized = TRUE,
  allele_labels = NULL,
  alpha = alpha,
  include_covars = TRUE,
  line_type = "l",
  pch = 16,
  cex = 0.5,
  lwd = 3,
  traits = NULL
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot.}

\item{\code{singlescan_obj}}{a singlescan object from \code{\link{singlescan}}}

\item{\code{width}}{width of result plot, default is 20.}

\item{\code{height}}{height of result plot, default is 6.}

\item{\code{units}}{units of result plot, default is "in".}

\item{\code{res}}{resolution of result plot, default is 300.}

\item{\code{standardized}}{If TRUE t statistics are plotted. If FALSE, effect sizes are plotted, default is TRUE}

\item{\code{allele_labels}}{A vector of labels for the alleles if different that those
stored in the data_object.}

\item{\code{alpha}}{the alpha significance level. Lines for significance values will only
be plotted if n_perm > 0 when \code{\link{singlescan}} was run. And only alpha values
specified in \code{\link{singlescan}} can be plotted.}

\item{\code{include_covars}}{Whether to include covariates in the plot.}

\item{\code{line_type}}{as defined in plot}

\item{\code{pch}}{see the "points()" R function. Default is 16 (a point).}

\item{\code{cex}}{see the "points()" R function. Default is 0.5.}

\item{\code{lwd}}{line width, default is 3.}

\item{\code{traits}}{a vector of trait names to plot. Defaults to all traits.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotPairscan"></a>}}
\if{latex}{\out{\hypertarget{method-plotPairscan}{}}}
\subsection{Method \code{plotPairscan()}}{
Plot the result of the pairwise scan
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotPairscan(
  filename,
  pairscan_obj,
  phenotype = NULL,
  show_marker_labels = TRUE,
  show_alleles = FALSE
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot.}

\item{\code{pairscan_obj}}{a pairscan object from \code{\link{pairscan}}}

\item{\code{phenotype}}{The names of the phenotypes to be plotted. If NULL, all phenotypes are plotted.}

\item{\code{show_marker_labels}}{If TRUE marker labels are plotted along the axes. If FALSE, they are omitted.}

\item{\code{show_alleles}}{If TRUE, the allele of each marker is indicated by color.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotVariantInfluences"></a>}}
\if{latex}{\out{\hypertarget{method-plotVariantInfluences}{}}}
\subsection{Method \code{plotVariantInfluences()}}{
Plot cape coefficients
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotVariantInfluences(
  filename,
  width = 10,
  height = 7,
  p_or_q = p_or_q,
  standardize = FALSE,
  not_tested_col = "lightgray",
  covar_width = NULL,
  pheno_width = NULL
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot.}

\item{\code{width}}{width of result plot, default is 10.}

\item{\code{height}}{height of result plot, default is 7.}

\item{\code{p_or_q}}{A threshold indicating the maximum p value (or q value if FDR was used) of significant 
interactions and main effects.}

\item{\code{standardize}}{Whether to plot effect sizes (FALSE) or standardized effect sizes (TRUE), 
default is TRUE.}

\item{\code{not_tested_col}}{The color to use for marker pairs not tested. Takes the same values as 
pos_col and neg_col, default is "lightgray".}

\item{\code{covar_width}}{See pheno_width. This is the same effect for covariates.}

\item{\code{pheno_width}}{Each marker and trait gets one column in the matrix. If there are many markers, 
this makes the effects on the traits difficult  to see. pheno_width increases the number of columns
given to the phenotypes. For example, if pheno_width = 11, the phenotypes will be shown 11 times wider
than individual markers.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotNetwork"></a>}}
\if{latex}{\out{\hypertarget{method-plotNetwork}{}}}
\subsection{Method \code{plotNetwork()}}{
Plots cape results as a circular network
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotNetwork(
  filename,
  label_gap = 10,
  label_cex = 1.5,
  show_alleles = FALSE
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot.}

\item{\code{label_gap}}{A numeric value indicating the size of the gap the chromosomes and their labels, 
default is 10.}

\item{\code{label_cex}}{A numeric value indicating the size of the labels, default is 1.5.}

\item{\code{show_alleles}}{TRUE show the alleles, FALSE does not show alleles. Default is FALSE.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-plotFullNetwork"></a>}}
\if{latex}{\out{\hypertarget{method-plotFullNetwork}{}}}
\subsection{Method \code{plotFullNetwork()}}{
Plot the final epistatic network in a traditional network view.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$plotFullNetwork(
  filename,
  zoom = 1.2,
  node_radius = 0.3,
  label_nodes = TRUE,
  label_offset = 0.4,
  label_cex = 0.5,
  bg_col = "lightgray",
  arrow_length = 0.1,
  layout_matrix = "layout_with_kk",
  legend_position = "topright",
  edge_lwd = 1,
  legend_radius = 2,
  legend_cex = 0.7,
  xshift = -1
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of result plot.}

\item{\code{zoom}}{Allows the user to zoom in and out on the image if the network is either 
running off the edges of the plot or too small in the middle of the plot, default is 1.2.}

\item{\code{node_radius}}{The size of the pie chart for each node, default is 0.3.}

\item{\code{label_nodes}}{A logical value indicating whether the nodes should be labeled.
Users may want to remove labels for large networks, default is TRUE.}

\item{\code{label_offset}}{The amount by which to offset the node labels from the center of
the nodes, default is 0.4.}

\item{\code{label_cex}}{The size of the node labels, default is 0.5.}

\item{\code{bg_col}}{The color to be used in pie charts for non-significant main effects.
Takes the same values as pos_col, default is "lightgray".}

\item{\code{arrow_length}}{The length of the head of the arrow, default is 0.1.}

\item{\code{layout_matrix}}{Users have the option of providing their own layout matrix for the
network. This should be a two column matrix indicating the x and y coordinates of each 
node in the network, default is "layout_with_kk".}

\item{\code{legend_position}}{The position of the legend on the plot, default is "topright".}

\item{\code{edge_lwd}}{The thickness of the arrows showing the interactions, default is 1.}

\item{\code{legend_radius}}{The size of the legend indicating which pie piece corresponds to which
traits, default is 2.}

\item{\code{legend_cex}}{The size of the labels in the legend, default is 0.7.}

\item{\code{xshift}}{A constant by which to shift the x values of all nodes in the network,
default is -1.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-writeVariantInfluences"></a>}}
\if{latex}{\out{\hypertarget{method-writeVariantInfluences}{}}}
\subsection{Method \code{writeVariantInfluences()}}{
Write significant cape interactions to a csv file.
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$writeVariantInfluences(
  filename,
  p_or_q = 0.05,
  include_main_effects = TRUE
)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{filename of csv file}

\item{\code{p_or_q}}{A threshold indicating the maximum adjusted p value considered 
significant. If an FDR method has been used to correct for multiple testing, 
this value specifies the maximum q value considered significant, default is 0.05.}

\item{\code{include_main_effects}}{Whether to include main effects (TRUE) or only
interaction effects (FALSE) in the output table, default is TRUE.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-set_pheno"></a>}}
\if{latex}{\out{\hypertarget{method-set_pheno}{}}}
\subsection{Method \code{set_pheno()}}{
Set phenotype
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$set_pheno(val)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{val}}{phenotype value.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-set_geno"></a>}}
\if{latex}{\out{\hypertarget{method-set_geno}{}}}
\subsection{Method \code{set_geno()}}{
Set genotype
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$set_geno(val)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{val}}{genotype value.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-create_covar_table"></a>}}
\if{latex}{\out{\hypertarget{method-create_covar_table}{}}}
\subsection{Method \code{create_covar_table()}}{
Create covariate table
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$create_covar_table(value)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{value}}{covariate values}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-save_rds"></a>}}
\if{latex}{\out{\hypertarget{method-save_rds}{}}}
\subsection{Method \code{save_rds()}}{
Save to RDS file
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$save_rds(object, filename)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{object}}{data to be saved.}

\item{\code{filename}}{filename of result RData file.}
}
\if{html}{\out{</div>}}
}
}
\if{html}{\out{<hr>}}
\if{html}{\out{<a id="method-read_rds"></a>}}
\if{latex}{\out{\hypertarget{method-read_rds}{}}}
\subsection{Method \code{read_rds()}}{
Read RDS file
\subsection{Usage}{
\if{html}{\out{<div class="r">}}\preformatted{Cape$read_rds(filename)}\if{html}{\out{</div>}}
}

\subsection{Arguments}{
\if{html}{\out{<div class="arguments">}}
\describe{
\item{\code{filename}}{RData filename to be read.}
}
\if{html}{\out{</div>}}
}
}
}
